/*
Copyright 2018 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	v1alpha1 "github.com/pingcap/tidb-operator/pkg/apis/pingcap.com/v1alpha1"
	scheme "github.com/pingcap/tidb-operator/pkg/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// TidbClustersGetter has a method to return a TidbClusterInterface.
// A group's client should implement this interface.
type TidbClustersGetter interface {
	TidbClusters(namespace string) TidbClusterInterface
}

// TidbClusterInterface has methods to work with TidbCluster resources.
type TidbClusterInterface interface {
	Create(*v1alpha1.TidbCluster) (*v1alpha1.TidbCluster, error)
	Update(*v1alpha1.TidbCluster) (*v1alpha1.TidbCluster, error)
	UpdateStatus(*v1alpha1.TidbCluster) (*v1alpha1.TidbCluster, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.TidbCluster, error)
	List(opts v1.ListOptions) (*v1alpha1.TidbClusterList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.TidbCluster, err error)
	TidbClusterExpansion
}

// tidbClusters implements TidbClusterInterface
type tidbClusters struct {
	client rest.Interface
	ns     string
}

// newTidbClusters returns a TidbClusters
func newTidbClusters(c *PingcapV1alpha1Client, namespace string) *tidbClusters {
	return &tidbClusters{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the tidbCluster, and returns the corresponding tidbCluster object, and an error if there is any.
func (c *tidbClusters) Get(name string, options v1.GetOptions) (result *v1alpha1.TidbCluster, err error) {
	result = &v1alpha1.TidbCluster{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("tidbclusters").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of TidbClusters that match those selectors.
func (c *tidbClusters) List(opts v1.ListOptions) (result *v1alpha1.TidbClusterList, err error) {
	result = &v1alpha1.TidbClusterList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("tidbclusters").
		VersionedParams(&opts, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested tidbClusters.
func (c *tidbClusters) Watch(opts v1.ListOptions) (watch.Interface, error) {
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("tidbclusters").
		VersionedParams(&opts, scheme.ParameterCodec).
		Watch()
}

// Create takes the representation of a tidbCluster and creates it.  Returns the server's representation of the tidbCluster, and an error, if there is any.
func (c *tidbClusters) Create(tidbCluster *v1alpha1.TidbCluster) (result *v1alpha1.TidbCluster, err error) {
	result = &v1alpha1.TidbCluster{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("tidbclusters").
		Body(tidbCluster).
		Do().
		Into(result)
	return
}

// Update takes the representation of a tidbCluster and updates it. Returns the server's representation of the tidbCluster, and an error, if there is any.
func (c *tidbClusters) Update(tidbCluster *v1alpha1.TidbCluster) (result *v1alpha1.TidbCluster, err error) {
	result = &v1alpha1.TidbCluster{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("tidbclusters").
		Name(tidbCluster.Name).
		Body(tidbCluster).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *tidbClusters) UpdateStatus(tidbCluster *v1alpha1.TidbCluster) (result *v1alpha1.TidbCluster, err error) {
	result = &v1alpha1.TidbCluster{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("tidbclusters").
		Name(tidbCluster.Name).
		SubResource("status").
		Body(tidbCluster).
		Do().
		Into(result)
	return
}

// Delete takes name of the tidbCluster and deletes it. Returns an error if one occurs.
func (c *tidbClusters) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("tidbclusters").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *tidbClusters) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("tidbclusters").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched tidbCluster.
func (c *tidbClusters) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.TidbCluster, err error) {
	result = &v1alpha1.TidbCluster{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("tidbclusters").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
